//
//  NotificationController.swift
//  MyDynamicNotification WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/04/16.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation


class NotificationController: WKUserNotificationInterfaceController {
    
    // titleを表示するラベル
    @IBOutlet weak var alertLabel: WKInterfaceLabel!
    // bodyを表示するラベル
    @IBOutlet weak var bodyLabel: WKInterfaceLabel!
    // 画像を表示するイメージ
    @IBOutlet weak var notifImage: WKInterfaceImage!

    override init() {
        // Initialize variables here.
        super.init()
        
        // Configure interface objects here.
    }

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

    // ローカル通知
    override func didReceiveLocalNotification(localNotification: UILocalNotification, withCompletion completionHandler: ((WKUserNotificationInterfaceType) -> Void)) {
        // （ローカル通知のDynamic Notification 画面はここで設定します）
        completionHandler(.Custom)
    }

    // リモート通知
    override func didReceiveRemoteNotification(remoteNotification: [NSObject : AnyObject], withCompletion completionHandler: ((WKUserNotificationInterfaceType) -> Void)) {

        // 通知内容からalertの内容を取り出す        
        let apsNotif = remoteNotification["aps"] as! Dictionary<String, AnyObject>
        let alertNotif = apsNotif["alert"] as! Dictionary<String, AnyObject>
        
        // titleの表示
        if let alertText = alertNotif["title"] as? String {
            // titleがnilでなければalertLabelに表示する
            alertLabel.setText(alertText)
            alertLabel.setHidden(false)
        } else {
            // titleがnilならばalertLabelを隠す
            alertLabel.setHidden(true)
        }
        
        // bodyの表示
        if let bodyText = alertNotif["body"] as? String {
            // bodyがnilでなければbodyLabelに表示する
            bodyLabel.setText(bodyText)
            bodyLabel.setHidden(false)
        } else {
            // bodyがnilならばbodyLabelを隠す
            bodyLabel.setHidden(true)
        }
        
        // 通知内容からlevelの内容を取り出す
        let level = remoteNotification["level"] as? String
        // levelでalertLabelの文字色を振り分ける
        switch level! {
        case "ordinal" :
            alertLabel.setTextColor(UIColor.greenColor())
        case "urgency" :
            alertLabel.setTextColor(UIColor.redColor())
        default :
            alertLabel.setTextColor(UIColor.whiteColor())
        }
        
        // 通知内容からimageNameの内容を取り出す
        if let imageName = remoteNotification["imageName"] as? String {
            // イメージをiPhone側から読み込んで表示する
            let imageData = UIImage(named: imageName)
            // Apple Watchを取得する
            let theWatch = WKInterfaceDevice.currentDevice()
            // キャッシュに読み込んで名前をつける
            let done = theWatch.addCachedImage(imageData!, name: "cashedImage")
            if done {
                // イメージを表示する
                notifImage.setImageNamed("cashedImage")
                notifImage.setHidden(false)
            } else {
                // イメージを取得できないときはnotifImageを隠す
                notifImage.setHidden(true)
            }
            
        } else {
            // イメージを取得できないときはnotifImageを隠す
            notifImage.setHidden(true)
        }
        
        // 通知画面の準備ができたのでDynamic Notificationを表示する
        completionHandler(.Custom)
    }

}

