//
//  ViewController.swift
//  localForeground
//
//  Created by yoshiyuki oshige on 2015/05/01.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import UIKit

class ViewController: UIViewController {
    // ラベルとOutlet接続する
    @IBOutlet weak var myLabel: UILabel!
    
    // 通知送信ボタンとAction接続する
    @IBAction func pressSendButton(sender: UIButton) {
        // ラベルを空にする
        updateLabel()
        // ローカル通知オブジェクトを作る
        var notification = UILocalNotification()
        // 通知カテゴリ
        notification.category = "myCategory"
        // 現在の時間から5秒後に通知する
        notification.fireDate = NSDate(timeIntervalSinceNow: 5)
        notification.timeZone = NSTimeZone.defaultTimeZone()
        notification.alertTitle = "パーティのご招待" // ショートルック画面
        notification.alertBody = "パーティのご招待" // ロングルック画面
        notification.alertAction = "OK"
        notification.soundName = UILocalNotificationDefaultSoundName
        notification.userInfo = ["customKey":"通知を受信しました。"]
        // 作成したローカル通知オブジェクトをスケジュールに入れる
        let sharedApp = UIApplication.sharedApplication()
        sharedApp.scheduleLocalNotification(notification)
    }
    
    // 通知センターの設定を行う
    func registerUserNotification() {
        // アクションactionAを作る
        var actionA = UIMutableUserNotificationAction()
        actionA.identifier = "acceptAction"
        actionA.title = "出席"
        // フォアグラウンドのアクション（アプリを起動する）
        actionA.activationMode = UIUserNotificationActivationMode.Foreground
        actionA.authenticationRequired = false
        actionA.destructive = true // 赤
        // アクションactionBを作る
        var actionB = UIMutableUserNotificationAction()
        actionB.identifier = "declineAction"
        actionB.title = "欠席"
        // バックグラウンドのアクション（アプリは起動しない）
        actionB.activationMode = UIUserNotificationActivationMode.Background
        actionB.authenticationRequired = false
        actionB.destructive = false // iOSでは青、Apple Watchでは白
        
        // 通知カテゴリmyCategoryを作る
        var myCategory = UIMutableUserNotificationCategory()
        // 通知カテゴリのidentifier
        myCategory.identifier = "myCategory"
        // 通知センターでの通知表示に使う設定
        myCategory.setActions([actionA, actionB], forContext: UIUserNotificationActionContext.Minimal)
        // アラートでの通知表示に使う設定
        myCategory.setActions([actionA, actionB], forContext: UIUserNotificationActionContext.Default)
        
        // カテゴリのセットにmyCategoryを追加する
        var categories = NSMutableSet()
        categories.addObject(myCategory)
        
        // 通知設定を作る
        var settings = UIUserNotificationSettings(forTypes: (.Alert | .Badge | .Sound),
            categories:categories as Set<NSObject>)
        // 通知センターに登録する
        UIApplication.sharedApplication().registerUserNotificationSettings(settings)
    }
    
    // ラベルのテキストを更新する
    func updateLabel(text:String? = "") {
        myLabel.text = text
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // ラベルを空にする
        updateLabel()
        // 通知センターの設定を行う
        registerUserNotification()
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
}
